==> moodle-1.4.3-pgsql.tgz: moodle/lang/ca/glossary.php <==
<?PHP // $Id$ 
      // glossary.php - created with Moodle 1.5 unstable development (2004091700)


$string['addcomment'] = 'Afegeix un comentari';
$string['addentry'] = 'Afegeix una entrada';
$string['addingcomment'] = 'S\'est afegint un comentari';
$string['aliases'] = 'Paraula o paraules clau';
$string['allcategories'] = 'Totes les categories';
$string['allentries'] = 'TOTES';
$string['allowcomments'] = 'Permeteu comentaris en les entrades?';
$string['allowduplicatedentries'] = 'Permeteu entrades duplicades?';
$string['allowratings'] = 'Permeteu valorar les entrades?';
$string['answer'] = 'Resposta';
$string['approve'] = 'D\'acord';
$string['areyousuredelete'] = 'Segur que voleu suprimir aquesta entrada?';
$string['areyousuredeletecomment'] = 'Segur que voleu suprimir aquest comentari?';
$string['areyousureexport'] = 'Segur que voleu exportar aquesta entrada a';
$string['ascending'] = '(s\'est pujant)';
$string['attachment'] = 'Fitxer adjunt';
$string['authorview'] = 'Ordenat per autor';
$string['back'] = 'Enrere';
$string['cantinsertcat'] = 'No s\'ha pogut inserir la categoria';
$string['cantinsertrec'] = 'No s\'ha pogut inserir el registre';
$string['cantinsertrel'] = 'No s\'ha pogut inserir la relaci categoria-entrada';
$string['casesensitive'] = 'Distingeix majscules i minscules';
$string['categories'] = 'Categories';
$string['category'] = 'Categoria';
$string['categorydeleted'] = 'La categoria s\'ha suprimit';
$string['categoryview'] = 'Navega per categories';
$string['cnfallowcomments'] = 'Definiu si els glossaris acceptaran comentaris en les entrades per defecte';
$string['cnfallowdupentries'] = 'Definiu si els glossaris permetran entrades duplicades per defecte';
$string['cnfapprovalstatus'] = 'Definiu si les entrades enviades pels estudiants quedaran aprovades per defecte';
$string['cnfcasesensitive'] = 'Definiu si per establir un enlla automtic es distingeixen per defecte majscules i minscules';
$string['cnfdefaulthook'] = 'Seleccioneu la selecci que es mostra per defecte quan el glossari s vist per primera vegada';
$string['cnfdefaultmode'] = 'Seleccioneu el marc que es mostra per defecte quan el glossari s vist per primera vegada.';
$string['cnffullmatch'] = 'Definiu si per establir un enlla automtic ha de coincidir  per defecte la paraula completa';
$string['cnflinkentry'] = 'Definiu si les entrades s\'han d\'enllaar automticament per defecte';
$string['cnflinkglossaries'] = 'Definiu si els glossaris s\'han d\'enllaar automticament per defecte';
$string['cnfrelatedview'] = 'Seleccioneu el format de visualitzaci dels enllaos automtics i de les entrades.';
$string['cnfshowgroup'] = 'Especifiqueu si el canvi de grup s\'ha de mostrar o no.';
$string['cnfsortkey'] = 'Seleccioneu el criteri d\'ordenaci per defecte.';
$string['cnfsortorder'] = 'Selecciona el sentit d\'ordenaci per defecte.';
$string['cnfstudentcanpost'] = 'Definiu si els estudiants poden enviar entrades per defecte o no.';
$string['comment'] = 'Comentari';
$string['commentdeleted'] = 'S\'ha suprimit el comentari.';
$string['comments'] = 'Comentaris';
$string['commentson'] = 'Comentaris actius';
$string['commentupdated'] = 'S\'ha actualitzat el comentari';
$string['concept'] = 'Concepte';
$string['concepts'] = 'Conceptes';
$string['configenablerssfeeds'] = 'Aquest commutador habilita la possibilitat de tenir RSS en tots els glossaris. Haureu d\'activar manualment l\'RSS en els parmetres de cada glossari.';
$string['currentglossary'] = 'Glossari actual';
$string['dateview'] = 'Navega per data';
$string['defaultapproval'] = 'Estat d\'aprovaci per defecte';
$string['definition'] = 'Definici';
$string['definitions'] = 'Definicions';
$string['deleteentry'] = 'Suprimeix entrada';
$string['deletingcomment'] = 'S\'est suprimint un comentari';
$string['deletingnoneemptycategory'] = 'Suprimir aquesta categoria no suprimir les entrades que cont: simplement aquestes es marcaran com a no categoritzades.';
$string['descending'] = '(descendent)';
$string['destination'] = 'Destinaci';
$string['displayformat'] = 'Format de visualitzaci';
$string['displayformatcontinuous'] = 'Continuat sense autor';
$string['displayformatdictionary'] = 'Simple, tipus diccionari';
$string['displayformatencyclopedia'] = 'Enciclopdia';
$string['displayformatentrylist'] = 'Llista d\'entrades';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'Complet amb autor';
$string['displayformatfullwithoutauthor'] = 'Complet sense autor';
$string['displayformats'] = 'Formats de visualitzaci';
$string['displayformatssetup'] = 'Configuraci dels formats de visualitzaci';
$string['duplicateentry'] = 'Entrada duplicada';
$string['editalways'] = 'Edita sempre';
$string['editcategories'] = 'Edita categories';
$string['editentry'] = 'Edita entrada';
$string['editingcomment'] = 'S\'est editant un comentari';
$string['entbypage'] = 'Nombre d\'entrades per pgina';
$string['entries'] = 'Entrades';
$string['entrieswithoutcategory'] = 'Entrades sense categoritzar';
$string['entry'] = 'Entrada';
$string['entryalreadyexist'] = 'L\'entrada ja existeix';
$string['entryapproved'] = 'S\'ha aprovat aquesta entrada';
$string['entrydeleted'] = 'S\'ha suprimit l\'entrada';
$string['entryexported'] = 'L\'entrada s\'ha exportat amb xit';
$string['entryishidden'] = '(aquesta entrada actualment est oculta)';
$string['entryleveldefaultsettings'] = 'Parmetres per defecte al nivell d\'entrada';
$string['entrysaved'] = 'S\'ha desat aquesta entrada';
$string['entryupdated'] = 'S\'ha actualitzat aquesta entrada';
$string['entryusedynalink'] = 'Aquesta entrada s\'ha d\'ennllaar automticament';
$string['explainaddentry'] = 'Afegiu una nova entrada al glossari actual.<br />El concepte i la definici sn camps obligatoris.';
$string['explainall'] = 'Visualitzeu TOTES les entrades en una pgina';
$string['explainalphabet'] = 'Navegueu pel glossari utilitzant aquest ndex';
$string['explainexport'] = 'S\'ha creat un fitxer.<br/ >Baixeu-lo i deseu-lo en lloc segur. Podeu importar-lo en qualsevol moment en aquest curs o en un altre.';
$string['explainimport'] = 'Heu d\'especificar el fitxer que voleu importar i definir els criteris del procs.<p>Trameteu la vostra sollicitud i reviseu els resultats.';
$string['explainspecial'] = 'Visualitzeu totes les entrades que no comencen per una lletra';
$string['exportedentry'] = 'Entrada exportada';
$string['exportedfile'] = 'Fitxer exportat';
$string['exportentries'] = 'Exporta entrades';
$string['exportglossary'] = 'Glossari exportat';
$string['exporttomainglossary'] = 'Exporta al glossari principal';
$string['filetoimport'] = 'Fitxer per importar';
$string['fillfields'] = 'El concepte i la definici sn camps obligatoris.';
$string['filtername'] = 'Enllaos automtics al glossari';
$string['fullmatch'] = 'Enllaa noms paraules completes';
$string['globalglossary'] = 'Glossari global';
$string['glossaryleveldefaultsettings'] = 'Parmetres per defecte al nivell de glossari';
$string['glossarytype'] = 'Tipus de glossari';
$string['glosssaryexported'] = 'S\'ha exportat el glossari.';
$string['importcategories'] = 'Importa categories';
$string['importedcategories'] = 'Categories importades';
$string['importedentries'] = 'Entrades importades';
$string['importentries'] = 'Importa entrades';
$string['isglobal'] = 'Aquest glossari s global?';
$string['linkcategory'] = 'Enllaa automticament aquesta categoria';
$string['mainglossary'] = 'Glossari principal';
$string['maxtimehaspassed'] = 'El temps mxim per editar aquest comentari ($a) ja ha passat!';
$string['modulename'] = 'Glossari';
$string['modulenameplural'] = 'Glossaris';
$string['newentries'] = 'Entrades noves del glossari';
$string['newglossary'] = 'Nou glossari';
$string['newglossarycreated'] = 'S\'ha creat un nou glossari.';
$string['newglossaryentries'] = 'Noves entrades del glossari:';
$string['nocomment'] = 'No s\'ha trobat cap comentari';
$string['nocomments'] = '(No s\'han trobat comentaris referents a aquesta entrada)';
$string['noconceptfound'] = 'No s\'ha trobat cap concepte ni definici.';
$string['noentries'] = 'No s\'han trobat entrades en aquesta secci';
$string['noentry'] = 'No s\'ha trobat cap entrada.';
$string['notcategorised'] = 'No categoritzat';
$string['numberofentries'] = 'Nombre d\'entrades';
$string['onebyline'] = '(una per lnia)';
$string['parentlanguage'] = '<<  TRADUCTORS: especifiqueu aqu el codi de l\'idioma que cal fer servir quan el vostre paquet d\'idioma no contingui una cadena. Si deixeu aquest camp en blanc s\'utilitzar l\'angls. Per exemple: es >>';
$string['printerfriendly'] = 'Versi per imprimir';
$string['question'] = 'Qesti';
$string['rate'] = 'Valoraci';
$string['rating'] = 'S\'est valorant';
$string['ratingeveryone'] = 'Qualsevol pot valorar les entrades';
$string['ratingno'] = 'Sense valoracions';
$string['ratingonlyteachers'] = 'Noms $a poden valorar entrades';
$string['ratings'] = 'Valoracions';
$string['ratingssaved'] = 'S\'han desat les valoracions';
$string['ratingsuse'] = 'Utilitza valoracions';
$string['ratingtime'] = 'Limita les valoracions a les entrades enviades en aquestes dates:';
$string['rejectedentries'] = 'Entrades rebutjades';
$string['rejectionrpt'] = 'Informe de rebuigs';
$string['rsssubscriberss'] = 'Visualitza l\'RSS \'$a\'';
$string['searchindefinition'] = 'Cerca en tot el text';
$string['secondaryglossary'] = 'Glossari secundari';
$string['sendinratings'] = 'Envia les meves darreres valoracions';
$string['showall'] = 'Mostra l\'enlla ';
$string['showalphabet'] = 'Mostra l\'alfabet';
$string['showspecial'] = 'Mostra l\'enlla ';
$string['sortby'] = 'Ordena per';
$string['sortbycreation'] = 'Per data de creaci';
$string['sortbylastupdate'] = 'Per l\'ltima actualitzaci';
$string['sortchronogically'] = 'Ordena cronolgicament';
$string['special'] = 'Especial';
$string['standardview'] = 'Navega alfabticament';
$string['studentcanpost'] = 'Els estudiants poden afegir entrades';
$string['thischarset'] = '<< TRADUCTORS: especifiqueu aqu el conjunt de carcters del vostre idioma. Teniu en compte que tot el text creat mentre aquest idioma sigui actiu s\'emmagatzemar amb aquest conjunt de carcters, de manera que s millor no tornar a canviar-lo. Per exemple: iso-8859-1 >>';
$string['thisdirection'] = '<< TRADUCTORS: aquesta cadena especifica el sentit del text, que pot ser d\'esquerra a dreta (\'ltr\') o de dreta a esquerra (\'rtl\'). >>';
$string['thislanguage'] = '<< TRADUCTORS: especifiqueu aqu el nom de l\'idioma. Si s possible utilitzeu referncies numriques Unicode >>';
$string['totalentries'] = 'Total d\'entrades';
$string['usedynalink'] = 'Enllaa automticament les entrades del glossari';
$string['waitingapproval'] = 'Esperant aprovaci';
$string['warningstudentcapost'] = '(Aplicable sols en cas que no sigui el glossari principal)';
$string['withauthor'] = 'Conceptes amb autor';
$string['withoutauthor'] = 'Conceptes sense autor';
$string['writtenby'] = 'Escrit per';
$string['youarenottheauthor'] = 'No sou l\'autor d\'aquest comentari, de manera que no podeu editar-lo.';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/ca/glossary.php <==
<?PHP // $Id$ 
      // glossary.php - created with Moodle 1.5 unstable development (2004091700)


$string['addcomment'] = 'Afegeix un comentari';
$string['addentry'] = 'Afegeix una entrada';
$string['addingcomment'] = 'S\'est afegint un comentari';
$string['aliases'] = 'Paraula o paraules clau';
$string['allcategories'] = 'Totes les categories';
$string['allentries'] = 'TOTES';
$string['allowcomments'] = 'Permeteu comentaris en les entrades?';
$string['allowduplicatedentries'] = 'Permeteu entrades duplicades?';
$string['allowratings'] = 'Permeteu valorar les entrades?';
$string['answer'] = 'Resposta';
$string['approve'] = 'D\'acord';
$string['areyousuredelete'] = 'Segur que voleu suprimir aquesta entrada?';
$string['areyousuredeletecomment'] = 'Segur que voleu suprimir aquest comentari?';
$string['areyousureexport'] = 'Segur que voleu exportar aquesta entrada a';
$string['ascending'] = '(ascendent)';
$string['attachment'] = 'Fitxer adjunt';
$string['authorview'] = 'Ordenat per autor';
$string['back'] = 'Enrere';
$string['cantinsertcat'] = 'No s\'ha pogut inserir la categoria';
$string['cantinsertrec'] = 'No s\'ha pogut inserir el registre';
$string['cantinsertrel'] = 'No s\'ha pogut inserir la relaci categoria-entrada';
$string['casesensitive'] = 'Distingeix majscules i minscules';
$string['categories'] = 'Categories';
$string['category'] = 'Categoria';
$string['categorydeleted'] = 'La categoria s\'ha suprimit';
$string['categoryview'] = 'Navega per categories';
$string['cnfallowcomments'] = 'Definiu si els glossaris acceptaran comentaris en les entrades per defecte';
$string['cnfallowdupentries'] = 'Definiu si els glossaris permetran entrades duplicades per defecte';
$string['cnfapprovalstatus'] = 'Definiu si les entrades enviades pels estudiants quedaran aprovades per defecte';
$string['cnfcasesensitive'] = 'Definiu si per establir un enlla automtic es distingeixen per defecte majscules i minscules';
$string['cnfdefaulthook'] = 'Seleccioneu la selecci que es mostra per defecte quan el glossari s vist per primera vegada';
$string['cnfdefaultmode'] = 'Seleccioneu el marc que es mostra per defecte quan el glossari s vist per primera vegada.';
$string['cnffullmatch'] = 'Definiu si per establir un enlla automtic ha de coincidir  per defecte la paraula completa';
$string['cnflinkentry'] = 'Definiu si les entrades s\'han d\'enllaar automticament per defecte';
$string['cnflinkglossaries'] = 'Definiu si els glossaris s\'han d\'enllaar automticament per defecte';
$string['cnfrelatedview'] = 'Seleccioneu el format de visualitzaci dels enllaos automtics i de les entrades.';
$string['cnfshowgroup'] = 'Especifiqueu si el canvi de grup s\'ha de mostrar o no.';
$string['cnfsortkey'] = 'Seleccioneu el criteri d\'ordenaci per defecte.';
$string['cnfsortorder'] = 'Selecciona el sentit d\'ordenaci per defecte.';
$string['cnfstudentcanpost'] = 'Definiu si els estudiants poden enviar entrades per defecte o no.';
$string['comment'] = 'Comentari';
$string['commentdeleted'] = 'S\'ha suprimit el comentari.';
$string['comments'] = 'Comentaris';
$string['commentson'] = 'Comentaris actius';
$string['commentupdated'] = 'S\'ha actualitzat el comentari';
$string['concept'] = 'Concepte';
$string['concepts'] = 'Conceptes';
$string['configenablerssfeeds'] = 'Aquest commutador habilita la possibilitat de tenir RSS en tots els glossaris. Haureu d\'activar manualment l\'RSS en els parmetres de cada glossari.';
$string['currentglossary'] = 'Glossari actual';
$string['dateview'] = 'Navega per data';
$string['defaultapproval'] = 'Estat d\'aprovaci per defecte';
$string['definition'] = 'Definici';
$string['definitions'] = 'Definicions';
$string['deleteentry'] = 'Suprimeix entrada';
$string['deletingcomment'] = 'S\'est suprimint un comentari';
$string['deletingnoneemptycategory'] = 'Suprimir aquesta categoria no suprimir les entrades que cont: simplement aquestes es marcaran com a no categoritzades.';
$string['descending'] = '(descendent)';
$string['destination'] = 'Destinaci';
$string['displayformat'] = 'Format de visualitzaci';
$string['displayformatcontinuous'] = 'Continu sense autor';
$string['displayformatdictionary'] = 'Simple, tipus diccionari';
$string['displayformatencyclopedia'] = 'Enciclopdia';
$string['displayformatentrylist'] = 'Llista d\'entrades';
$string['displayformatfaq'] = 'PMF (FAQ)';
$string['displayformatfullwithauthor'] = 'Complet amb autor';
$string['displayformatfullwithoutauthor'] = 'Complet sense autor';
$string['displayformats'] = 'Formats de visualitzaci';
$string['displayformatssetup'] = 'Configuraci dels formats de visualitzaci';
$string['duplicateentry'] = 'Entrada duplicada';
$string['editalways'] = 'Edita sempre';
$string['editcategories'] = 'Edita categories';
$string['editentry'] = 'Edita entrada';
$string['editingcomment'] = 'S\'est editant un comentari';
$string['entbypage'] = 'Nombre d\'entrades per pgina';
$string['entries'] = 'Entrades';
$string['entrieswithoutcategory'] = 'Entrades sense categoritzar';
$string['entry'] = 'Entrada';
$string['entryalreadyexist'] = 'L\'entrada ja existeix';
$string['entryapproved'] = 'S\'ha aprovat aquesta entrada';
$string['entrydeleted'] = 'S\'ha suprimit l\'entrada';
$string['entryexported'] = 'L\'entrada s\'ha exportat amb xit';
$string['entryishidden'] = '(aquesta entrada actualment est oculta)';
$string['entryleveldefaultsettings'] = 'Parmetres per defecte al nivell d\'entrada';
$string['entrysaved'] = 'S\'ha desat aquesta entrada';
$string['entryupdated'] = 'S\'ha actualitzat aquesta entrada';
$string['entryusedynalink'] = 'Aquesta entrada s\'ha d\'enllaar automticament';
$string['explainaddentry'] = 'Afegiu una nova entrada al glossari actual.<br />El concepte i la definici sn camps obligatoris.';
$string['explainall'] = 'Visualitzeu TOTES les entrades en una pgina';
$string['explainalphabet'] = 'Navegueu pel glossari utilitzant aquest ndex';
$string['explainexport'] = 'S\'ha creat un fitxer.<br/ >Baixeu-lo i deseu-lo en lloc segur. Podeu importar-lo en qualsevol moment en aquest curs o en un altre.';
$string['explainimport'] = 'Heu d\'especificar el fitxer que voleu importar i definir els criteris del procs.<p>Trameteu la vostra sollicitud i reviseu els resultats.';
$string['explainspecial'] = 'Visualitzeu totes les entrades que no comencen per una lletra';
$string['exportedentry'] = 'Entrada exportada';
$string['exportedfile'] = 'Fitxer exportat';
$string['exportentries'] = 'Exporta entrades';
$string['exportglossary'] = 'Glossari exportat';
$string['exporttomainglossary'] = 'Exporta al glossari principal';
$string['filetoimport'] = 'Fitxer per importar';
$string['fillfields'] = 'El concepte i la definici sn camps obligatoris.';
$string['filtername'] = 'Enllaos automtics al glossari';
$string['fullmatch'] = 'Enllaa noms paraules completes';
$string['globalglossary'] = 'Glossari global';
$string['glossaryleveldefaultsettings'] = 'Parmetres per defecte al nivell de glossari';
$string['glossarytype'] = 'Tipus de glossari';
$string['glosssaryexported'] = 'S\'ha exportat el glossari.';
$string['importcategories'] = 'Importa categories';
$string['importedcategories'] = 'Categories importades';
$string['importedentries'] = 'Entrades importades';
$string['importentries'] = 'Importa entrades';
$string['isglobal'] = 'Aquest glossari s global?';
$string['linkcategory'] = 'Enllaa automticament aquesta categoria';
$string['mainglossary'] = 'Glossari principal';
$string['maxtimehaspassed'] = 'El temps mxim per editar aquest comentari ($a) ja ha passat!';
$string['modulename'] = 'Glossari';
$string['modulenameplural'] = 'Glossaris';
$string['newentries'] = 'Entrades noves del glossari';
$string['newglossary'] = 'Nou glossari';
$string['newglossarycreated'] = 'S\'ha creat un nou glossari.';
$string['newglossaryentries'] = 'Noves entrades del glossari:';
$string['nocomment'] = 'No s\'ha trobat cap comentari';
$string['nocomments'] = '(No s\'han trobat comentaris referents a aquesta entrada)';
$string['noconceptfound'] = 'No s\'ha trobat cap concepte ni definici.';
$string['noentries'] = 'No s\'han trobat entrades en aquesta secci';
$string['noentry'] = 'No s\'ha trobat cap entrada.';
$string['notcategorised'] = 'No categoritzat';
$string['numberofentries'] = 'Nombre d\'entrades';
$string['onebyline'] = '(una per lnia)';
$string['printerfriendly'] = 'Versi per imprimir';
$string['question'] = 'Qesti';
$string['rate'] = 'Valoraci';
$string['rating'] = 'S\'est valorant';
$string['ratingeveryone'] = 'Qualsevol pot valorar les entrades';
$string['ratingno'] = 'Sense valoracions';
$string['ratingonlyteachers'] = 'Noms $a poden valorar entrades';
$string['ratings'] = 'Valoracions';
$string['ratingssaved'] = 'S\'han desat les valoracions';
$string['ratingsuse'] = 'Utilitza valoracions';
$string['ratingtime'] = 'Limita les valoracions a les entrades enviades en aquestes dates:';
$string['rejectedentries'] = 'Entrades rebutjades';
$string['rejectionrpt'] = 'Informe de rebuigs';
$string['rsssubscriberss'] = 'Visualitza l\'RSS \'$a\'';
$string['searchindefinition'] = 'Cerca en tot el text';
$string['secondaryglossary'] = 'Glossari secundari';
$string['sendinratings'] = 'Envia les meves darreres valoracions';
$string['showall'] = 'Mostra l\'enlla ';
$string['showalphabet'] = 'Mostra l\'alfabet';
$string['showspecial'] = 'Mostra l\'enlla ';
$string['sortby'] = 'Ordena per';
$string['sortbycreation'] = 'Per data de creaci';
$string['sortbylastupdate'] = 'Per l\'ltima actualitzaci';
$string['sortchronogically'] = 'Ordena cronolgicament';
$string['special'] = 'Especial';
$string['standardview'] = 'Navega alfabticament';
$string['studentcanpost'] = 'Els estudiants poden afegir entrades';
$string['totalentries'] = 'Total d\'entrades';
$string['usedynalink'] = 'Enllaa automticament les entrades del glossari';
$string['waitingapproval'] = 'Esperant aprovaci';
$string['warningstudentcapost'] = '(Aplicable noms en cas que no sigui el glossari principal)';
$string['withauthor'] = 'Conceptes amb autor';
$string['withoutauthor'] = 'Conceptes sense autor';
$string['writtenby'] = 'Escrit per';
$string['youarenottheauthor'] = 'No sou l\'autor d\'aquest comentari, de manera que no podeu editar-lo.';

?>
